@@ -35,7 +35,7 @@ from libs.canvas import Canvas
 from libs.zoomWidget import ZoomWidget
 from libs.labelDialog import LabelDialog
 from libs.excelDialog import ExcelDialog
-from libs.prueba import Ui_Dialog
+from libs.stomaExcel import Ui_Dialog1
 from libs.colorDialog import ColorDialog
 from libs.labelFile import LabelFile, LabelFileError
 from libs.toolBar import ToolBar
@@ -1451,12 +1451,12 @@ class MainWindow(QMainWindow, WindowMixin):
     def generarExcel(self):
         self.saveFile()
         Dialog = QtWidgets.QDialog()
-        ui = Ui_Dialog()
-        ui.setupUi(Dialog)
+        ui = Ui_Dialog1()
+        ui.setupUi1(Dialog)
         x = Dialog.exec_()
         if ui.genera:
             try:
-                generaExcel(os.path.dirname(ustr(self.filePath)), ui.esca, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
+                generaExcel(os.path.dirname(ustr(self.filePath)), ui.escaStoma, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
                 self.setWindowIcon(QtGui.QIcon("resources/icons/excel.png"))
                 QMessageBox.about(self, "Information", "Excel finished")
                 self.setWindowIcon(newIcon("app"))
@@ -1499,7 +1499,7 @@ class MainWindow(QMainWindow, WindowMixin):
         QMessageBox.about(self, "Information", "Notebook finished and save in " + path)
 
     def handleNewWindow(self):
-        self.childWindow = Ui_Dialog(self)
+        self.childWindow = Ui_Dialog1(self)
 
     def saveFile(self, _value=False):
         if self.shapeSize is None:
